@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -240,6 +240,73 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -290,57 +357,22 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
-            "true",
-            "false",
-        ):
-            raise ValueError(
-                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
-            )
-        use_client_cert = (
-            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, ConnectionServiceTransport):
             # transport is a ConnectionServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -352,6 +384,15 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -377,6 +418,25 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
     ) -> gcbc_connection.Connection:
         r"""Creates a new connection.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_create_connection():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.CreateConnectionRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_connection(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.CreateConnectionRequest, dict]):
                 The request object. The request for
@@ -414,7 +474,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, connection, connection_id])
         if request is not None and has_flattened_params:
@@ -465,6 +525,25 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
     ) -> connection.Connection:
         r"""Returns specified connection.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_get_connection():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.GetConnectionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_connection(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.GetConnectionRequest, dict]):
                 The request object. The request for
@@ -490,7 +569,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -537,6 +616,27 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
     ) -> pagers.ListConnectionsPager:
         r"""Returns a list of connections in the given project.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_list_connections():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.ListConnectionsRequest(
+                    parent="parent_value",
+                    page_size=951,
+                )
+
+                # Make the request
+                page_result = client.list_connections(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.ListConnectionsRequest, dict]):
                 The request object. The request for
@@ -564,7 +664,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -621,6 +721,26 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         reasons, also resets credential if connection properties
         are in the update field mask.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_update_connection():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.UpdateConnectionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.update_connection(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.UpdateConnectionRequest, dict]):
                 The request object. The request for
@@ -660,7 +780,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, connection, update_mask])
         if request is not None and has_flattened_params:
@@ -711,6 +831,22 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
     ) -> None:
         r"""Deletes connection and associated credential.
 
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_delete_connection():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.DeleteConnectionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_connection(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.DeleteConnectionRequest, dict]):
                 The request object. The request for
@@ -729,7 +865,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -777,6 +913,26 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         Returns an empty policy if the resource exists and does
         not have a policy set.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_get_iam_policy():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -856,7 +1012,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -906,6 +1062,26 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         Can return ``NOT_FOUND``, ``INVALID_ARGUMENT``, and
         ``PERMISSION_DENIED`` errors.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_set_iam_policy():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -985,7 +1161,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -1039,6 +1215,27 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
         authorization checking. This operation may "fail open" without
         warning.
 
+
+        .. code-block:: python
+
+            from google.cloud import bigquery_connection_v1
+
+            def sample_test_iam_permissions():
+                # Create a client
+                client = bigquery_connection_v1.ConnectionServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_connection_v1.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
@@ -1072,7 +1269,7 @@ class ConnectionServiceClient(metaclass=ConnectionServiceClientMeta):
                 Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource, permissions])
         if request is not None and has_flattened_params:
